@@ -19,7 +19,8 @@ CREATE FUNCTION plpgsql_check_function_tb(funcoid regprocedure,
                                        without_warnings boolean DEFAULT false,
                                        all_warnings boolean DEFAULT false,
                                        use_incomment_options boolean DEFAULT true,
-                                       incomment_options_usage_warning boolean DEFAULT false)
+                                       incomment_options_usage_warning boolean DEFAULT false,
+                                       constant_tracing boolean DEFAULT true)
 RETURNS TABLE(functionid regproc,
               lineno int,
               statement text,
@@ -53,7 +54,8 @@ CREATE FUNCTION plpgsql_check_function(funcoid regprocedure,
                                        without_warnings boolean DEFAULT false,
                                        all_warnings boolean DEFAULT false,
                                        use_incomment_options boolean DEFAULT true,
-                                       incomment_options_usage_warning boolean DEFAULT false)
+                                       incomment_options_usage_warning boolean DEFAULT false,
+                                       constant_tracing boolean DEFAULT true)
 RETURNS SETOF text
 AS 'MODULE_PATHNAME','plpgsql_check_function'
 LANGUAGE C;
@@ -76,7 +78,8 @@ CREATE FUNCTION plpgsql_check_function_tb(name text,
                                        without_warnings boolean DEFAULT false,
                                        all_warnings boolean DEFAULT false,
                                        use_incomment_options boolean DEFAULT true,
-                                       incomment_options_usage_warning boolean DEFAULT false)
+                                       incomment_options_usage_warning boolean DEFAULT false,
+                                       constant_tracing boolean DEFAULT true)
 RETURNS TABLE(functionid regproc,
               lineno int,
               statement text,
@@ -110,30 +113,49 @@ CREATE FUNCTION plpgsql_check_function(name text,
                                        without_warnings boolean DEFAULT false,
                                        all_warnings boolean DEFAULT false,
                                        use_incomment_options boolean DEFAULT true,
-                                       incomment_options_usage_warning boolean DEFAULT false)
+                                       incomment_options_usage_warning boolean DEFAULT false,
+                                       constant_tracing boolean DEFAULT true)
 RETURNS SETOF text
 AS 'MODULE_PATHNAME','plpgsql_check_function_name'
 LANGUAGE C;
 
-CREATE FUNCTION __plpgsql_show_dependency_tb(funcoid regprocedure, relid regclass DEFAULT 0)
+CREATE FUNCTION __plpgsql_show_dependency_tb(funcoid regprocedure,
+                                             relid regclass DEFAULT 0,
+                                             anyelememttype regtype DEFAULT 'int',
+                                             anyenumtype regtype DEFAULT '-',
+                                             anyrangetype regtype DEFAULT 'int4range',
+                                             anycompatibletype regtype DEFAULT 'int',
+                                             anycompatiblerangetype regtype DEFAULT 'int4range')
 RETURNS TABLE(type text,
               oid oid,
               schema text,
               name text,
               params text)
 AS 'MODULE_PATHNAME','plpgsql_show_dependency_tb'
-LANGUAGE C STRICT;
+LANGUAGE C;
 
-CREATE FUNCTION __plpgsql_show_dependency_tb(name text, relid regclass DEFAULT 0)
+CREATE FUNCTION __plpgsql_show_dependency_tb(name text,
+                                             relid regclass DEFAULT 0,
+                                             anyelememttype regtype DEFAULT 'int',
+                                             anyenumtype regtype DEFAULT '-',
+                                             anyrangetype regtype DEFAULT 'int4range',
+                                             anycompatibletype regtype DEFAULT 'int',
+                                             anycompatiblerangetype regtype DEFAULT 'int4range')
 RETURNS TABLE(type text,
               oid oid,
               schema text,
               name text,
               params text)
 AS 'MODULE_PATHNAME','plpgsql_show_dependency_tb_name'
-LANGUAGE C STRICT;
+LANGUAGE C;
 
-CREATE FUNCTION plpgsql_show_dependency_tb(funcoid regprocedure, relid regclass DEFAULT 0)
+CREATE FUNCTION plpgsql_show_dependency_tb(funcoid regprocedure,
+                                           relid regclass DEFAULT 0,
+                                           anyelememttype regtype DEFAULT 'int',
+                                           anyenumtype regtype DEFAULT '-',
+                                           anyrangetype regtype DEFAULT 'int4range',
+                                           anycompatibletype regtype DEFAULT 'int',
+                                           anycompatiblerangetype regtype DEFAULT 'int4range')
 RETURNS TABLE(type text,
               oid oid,
               schema text,
@@ -141,11 +163,17 @@ RETURNS TABLE(type text,
               params text)
 AS $$
   SELECT *
-    FROM @extschema@.__plpgsql_show_dependency_tb($1, $2)
+    FROM @extschema@.__plpgsql_show_dependency_tb($1, $2, $3, $4, $5, $6, $7)
    ORDER BY 1, 3, 4;
 $$ LANGUAGE sql;
 
-CREATE FUNCTION plpgsql_show_dependency_tb(fnname text, relid regclass DEFAULT 0)
+CREATE FUNCTION plpgsql_show_dependency_tb(fnname text,
+                                           relid regclass DEFAULT 0,
+                                           anyelememttype regtype DEFAULT 'int',
+                                           anyenumtype regtype DEFAULT '-',
+                                           anyrangetype regtype DEFAULT 'int4range',
+                                           anycompatibletype regtype DEFAULT 'int',
+                                           anycompatiblerangetype regtype DEFAULT 'int4range')
 RETURNS TABLE(type text,
               oid oid,
               schema text,
@@ -153,7 +181,7 @@ RETURNS TABLE(type text,
               params text)
 AS $$
   SELECT *
-    FROM @extschema@.__plpgsql_show_dependency_tb($1, $2)
+    FROM @extschema@.__plpgsql_show_dependency_tb($1, $2, $3, $4, $5, $6, $7)
    ORDER BY 1, 3, 4;
 $$ LANGUAGE sql;
 
@@ -268,3 +296,11 @@ RETURNS TABLE(funcoid regprocedure,
               max_time double precision)
 AS 'MODULE_PATHNAME','plpgsql_profiler_functions_all_tb'
 LANGUAGE C STRICT;
+
+CREATE OR REPLACE FUNCTION plpgsql_check_profiler(enable boolean DEFAULT NULL)
+RETURNS boolean AS 'MODULE_PATHNAME', 'plpgsql_check_profiler_ctrl'
+LANGUAGE C VOLATILE;
+
+CREATE OR REPLACE FUNCTION plpgsql_check_tracer(enable boolean DEFAULT NULL, verbosity text DEFAULT NULL)
+RETURNS boolean AS 'MODULE_PATHNAME', 'plpgsql_check_tracer_ctrl'
+LANGUAGE C VOLATILE;
\ No newline at end of file
